History
=======

The codes in this package were developed as a demonstration of a few posts of my blog.
It was not designed to be a Python package but a pedagogical collection of codes.
(See: PyTDA_ .)
However, the codes and the blog posts have been unexpectedly popular. Therefore,
I modularized the code into the package mogu_ . (or corresponding repository: MoguNumerics_)
However, `mogu` is simply a collection of unrelated numerical routines with a lot of
dependencies, but the part of TDA can be quite independent.

In order to provide other researchers and developers an independent package, which is compact (without
unnecessary alternative packages to load), and efficient, I decided to modularize
the codes of TDA separately, and name this package `mogutda`.

.. _mogu: https://pypi.org/project/mogu/
.. _PyTDA: https://github.com/stephenhky/PyTDA
.. _MoguNumerics: https://github.com/stephenhky/MoguNumerics

Home: :doc:`index`